@@ -1,9 +1,9 @@
 export2pdf <- function(x, file, which.table="descr", nmax=TRUE, header.labels=c(), caption=NULL, 
                        width=Inf, strip=FALSE, first.strip=FALSE, background="#D2D2D2", size=NULL,  
-                       landscape=FALSE, numcompiled=2){
+                       landscape=FALSE, numcompiled=2, header.background=NULL, header.color=NULL){
 
   
-  if (!inherits(x, "createTable")) 
+  if (!inherits(x, "createTable"))
     stop("x must be of class 'createTable'")
 
   if (length(header.labels)==0) header.labels<-"c()"
@@ -29,7 +29,8 @@ output: pdf_document
 ```{r, echo=FALSE}\n
 export2md(x, which.table=which.table, nmax=nmax, header.labels=header.labels, 
 caption=caption, width=width,format='latex', strip=strip, 
-first.strip=first.strip, background=background, size=size, landscape=landscape)\n
+first.strip=first.strip, background=background, size=size, landscape=landscape,
+header.color=header.color, header.background=header.background)\n
 ```\n
 \n"
 ,sep=""
